<?php
/*
 * Plugin Name: Mimoza Yorumlar
 * Description: Web siteniz üzerinden kullanıcı yorumları ve yıldız derecelendirmeleri alıp yayınlamanızı sağlayan ücretsiz bir WordPress eklentisi.
 * Version: 1.0
 * Author: Mimoza Bilişim (Onur Kalafat)
 * License: GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */




// Ayarlar sayfasını oluşturma fonksiyonu
function mimoza_yorumlar_settings_page() {
    ?>
    <div class="wrap">
        <h2>Mimoza Yorumlar Ayarları</h2>
        <form method="post" action="options.php">
            <?php settings_fields('mimoza_yorumlar_options_group'); ?>
            <?php do_settings_sections('mimoza_yorumlar'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">reCAPTCHA Site Anahtarı</th>
                    <td>
                        <input type="text" name="mimoza_yorumlar_recaptcha_site_key" value="<?php echo esc_attr(get_option('mimoza_yorumlar_recaptcha_site_key')); ?>" />
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">reCAPTCHA Gizli Anahtarı</th>
                    <td>
                        <input type="text" name="mimoza_yorumlar_recaptcha_secret_key" value="<?php echo esc_attr(get_option('mimoza_yorumlar_recaptcha_secret_key')); ?>" />
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}





// Ayarlar menüsüne ayar sayfası ekleme
function mimoza_yorumlar_menu() {
    add_options_page('Mimoza Yorumlar Ayarları', 'Mimoza Yorumlar', 'manage_options', 'mimoza_yorumlar', 'mimoza_yorumlar_settings_page');
}

add_action('admin_menu', 'mimoza_yorumlar_menu');



// Ayarları kaydetmek için gerekli alanların kaydı
function mimoza_yorumlar_register_settings() {
    register_setting('mimoza_yorumlar_options_group', 'mimoza_yorumlar_recaptcha_site_key');
    register_setting('mimoza_yorumlar_options_group', 'mimoza_yorumlar_recaptcha_secret_key');
}

add_action('admin_init', 'mimoza_yorumlar_register_settings');



// Eklentinin diğer fonksiyonları ve hook'ları burada devam eder


// Bu fonksiyon, Google reCAPTCHA scriptini yükler
function load_recaptcha_script() {
    wp_enqueue_script('google-recaptcha', 'https://www.google.com/recaptcha/api.js', array(), null, true);
}

// WordPress'e, script yükleme işlemini doğru zamanda yapması için talimat verir
add_action('wp_enqueue_scripts', 'load_recaptcha_script');

// Diğer eklenti fonksiyonlarınız ve kodlarınız burada


function add_custom_text_to_header() {
    echo '<p></p>';
}
add_action('wp_head', 'add_custom_text_to_header');

function mimoza_register_review_post_type() {
    $args = array(
        'public' => true,
        'label'  => 'Reviews',
        'supports' => array('title', 'editor', 'author', 'thumbnail', 'excerpt', 'comments'),
    );
    register_post_type('reviews', $args);
}

function handle_form_submission() {
    // Nonce kontrolü ve form gönderimi var mı kontrol et
    if (isset($_POST['submit_rating']) && check_admin_referer('submit_rating_nonce', '_rating_nonce')) {
        $name = sanitize_text_field($_POST['name']);
        $email = sanitize_email($_POST['email']);
        $comment = sanitize_textarea_field($_POST['comment']);
        $rating = intval($_POST['rating']);

        $post_id = wp_insert_post(array(
            'post_title'   => wp_strip_all_tags($name . "'s Review"),
            'post_content' => $comment,
            'post_status'  => 'pending',
            'post_type'    => 'reviews',
            'post_author'  => 1,
        ));

        if (!is_wp_error($post_id)) {
            add_post_meta($post_id, 'rating', $rating);

            // Yönlendirme ve teşekkür mesajı
            wp_redirect(add_query_arg('submitted', 'true', get_permalink()));
            exit;
        }
    }
}


function display_reviews_and_ratings() {
    $args = array(
        'post_type' => 'reviews',
        'posts_per_page' => -1,
        'orderby' => 'date',
        'order' => 'DESC'
    );

    $reviews_query = new WP_Query($args);

    if ($reviews_query->have_posts()) {
        echo '<div class="reviews-container">';

        while ($reviews_query->have_posts()) {
            $reviews_query->the_post();
            $rating = get_post_meta(get_the_ID(), 'rating', true);

            echo '<div class="review-box">';
            echo '<h3>' . get_the_title() . '</h3>';
            echo '<div class="rating">Derecelendirme: ' . $rating . ' / 5</div>';
            echo '<div class="content">' . get_the_content() . '</div>';
            echo '</div>';
        }

        echo '</div>';
    } else {
        echo 'Henüz yorum yapılmamış.';
    }

    wp_reset_postdata();
}

function reviews_ratings_shortcode() {
    ob_start();
    display_reviews_and_ratings();
    return ob_get_clean();
}
add_shortcode('show_reviews_ratings', 'reviews_ratings_shortcode');

function my_custom_plugin_styles() {
    wp_enqueue_style('my-custom-plugin-style', plugin_dir_url(__FILE__) . 'style.css');
}
add_action('wp_enqueue_scripts', 'my_custom_plugin_styles');

add_action('init', 'mimoza_register_review_post_type');
add_action('init', 'handle_form_submission');


// Formu gösteren fonksiyon
function show_rating_form1() {
    // Form gönderildikten sonra bir teşekkür mesajı göster
    if (isset($_POST['submit_rating'])) {
        echo '<p>Teşekkürler! Yorumunuz onaylandıktan sonra yayınlanacak.</p>';
    }

    ?>
    <form action="" method="post">
    <?php wp_nonce_field('submit_rating_nonce', '_rating_nonce'); ?>
    <label for="name">Adınız:</label>
    <input type="text" id="name" name="name" required>

    <label for="email">E-posta Adresiniz:</label>
    <input type="email" id="email" name="email" required>

    <label for="comment">Yorumunuz:</label>
    <textarea id="comment" name="comment" required></textarea>

    <label for="rating">Derecelendirme:</label>
    <select id="rating" name="rating">
        <option value="5">★★★★★</option>
        <option value="4">★★★★</option>
        <option value="3">★★★</option>
        <option value="2">★★</option>
        <option value="1">★</option>
    </select>

    <!-- Google reCAPTCHA widget -->
    <div class="g-recaptcha" data-sitekey="<?php echo esc_attr(get_option('mimoza_yorumlar_recaptcha_site_key')); ?>"></div>

    <input type="submit" name="submit_rating" value="Yorumu Gönder">
</form>

    <?php
}




// Formu gösteren shortcode
function rating_form_shortcode() {
    ob_start();
    show_rating_form1();
    return ob_get_clean();
}
add_shortcode('musteri_yorumu', 'rating_form_shortcode');



